@@ -37,44 +37,48 @@
 
 /* Standard test functions.
  * init: parses and verifies cmd-line args (URL, username/password)
- * test_connect: checks that server is running.
- * open_foo: opens the dummy 'foo' file.
+ * direct_connect: tests direct connection (optional, not recommended)
  * begin: opens session 'i_session' to server.
  * options: does an OPTIONS request on i_path, sets i_class2.
  * finish: closes i_session. */
 
-TF(init); TF(begin);
+TF(init); TF(begin); TF(direct_connect);
 TF(options); TF(finish);
 
 /* Standard initialisers for tests[] array: start everything up: */
-#define INIT_TESTS T(init), T(begin)
+#define INIT_TESTS T(begin)
 
 /* And finish everything off */
 #define FINISH_TESTS T(finish), T(NULL)
 
-/* The sesssion to use. */
+/* The session to use. */
 extern ne_session *i_session, *i_session2;
 
 /* server details. */
-extern const char *i_hostname;
-extern unsigned int i_port;
+extern ne_uri i_origin;
+#define i_path (i_origin.path)
+#define i_port (i_origin.port)
+#define i_hostname (i_origin.host)
+
+/* If test_direct_connect() is invoked, this will be non-NULL. */
 extern ne_sock_addr *i_address;
-extern char *i_path;
 
 extern int i_class2; /* true if server is a class 2 DAV server. */
 
-/* If open_foo() has been called, this is the fd to the 'foo' file. */
-extern int i_foo_fd;
-
-/* size of file in foo */
-extern off_t i_foo_len;
-
 /* Upload htdocs/foo to i_path + path */
 int upload_foo(const char *path);
 
 /* Returns etag of resource at path within i_session */
 char *get_etag(const char *path);
 
+/* PUT request with body of "zero" to path. Returns NE_ERROR for
+ * non-2xx responses. */
+int dummy_put(ne_session *sess, const char *path);
+
+/* PUT request to 'path' with request body NUL-terminated string
+ * 'content'. */
+int put_buffer(ne_session *sess, const char *path, const char *content);
+
 /* for method 'method' on 'uri', do operation 'x'. */
 #define ONMREQ(method, uri, x) do { int _ret = (x); if (_ret) { t_context("%s on `%s': %s", method, uri, ne_get_error(i_session)); return FAIL; } } while (0)
 
@@ -96,8 +100,4 @@ char *get_etag(const char *path);
 #define GETSTATUS2 (atoi(ne_get_error((i_session2))))
 #define STATUS2(code) (GETSTATUS2 != (code))
 
-#if NE_VERSION_MAJOR > 0 || NE_VERSION_MINOR > 25
-#define HAVE_NEON_026PLUS /* at least neon 0.26.x. */
-#endif
-
 #endif /* INTEROP_H */
