@@ -83,7 +83,7 @@ static int getlock(enum ne_lock_scope scope, int depth)
     ONMREQ("LOCK", res, ne_lock(i_session, &reslock));
     
     if (scope != reslock.scope) {
-        t_context("requested lockscope not satisfied!  got %s, wanted %s",
+        t_context("requested lockscope not satisfied!  wanted %s, got %s",
                   scope == ne_lockscope_exclusive ? "exclusive" : "shared",
                   reslock.scope == ne_lockscope_exclusive ? 
                   "exclusive" : "shared");
@@ -148,7 +148,7 @@ static int notowner_modify(void)
 	t_warning("PROPPATCH failed with %d not 423", GETSTATUS2);
 
     ONN("PUT on locked resource should fail",
-	ne_put(i_session2, res, i_foo_fd) != NE_ERROR);
+	dummy_put(i_session2, res) != NE_ERROR);
 
     if (STATUS2(423))
 	t_warning("PUT failed with %d not 423", GETSTATUS2);
@@ -217,10 +217,10 @@ static int owner_modify(void)
     
     pops[0].name = &pname;
 
-    ONV(ne_put(i_session, res, i_foo_fd),
+    ONV(dummy_put(i_session, res),
 	("PUT on locked resource failed: %s", ne_get_error(i_session)));
 
-    ONMREQ("PROPPATCH on locked resouce", res,
+    ONMREQ("PROPPATCH on locked resource", res,
            ne_proppatch(i_session, res, pops));
     
     return OK;
@@ -228,11 +228,7 @@ static int owner_modify(void)
 
 /* ne_lock_discover which counts number of calls. */
 static void count_discover(void *userdata, const struct ne_lock *lock,
-#ifdef HAVE_NEON_026PLUS
                            const ne_uri *uri,
-#else
-			   const char *uri, 
-#endif
                            const ne_status *status)
 {
     if (lock) {
@@ -280,11 +276,7 @@ static int compare_locks(const struct ne_lock *exp, const struct ne_lock *act)
 
 /* check that the lock returned has correct URI, token */
 static void verify_discover(void *userdata, const struct ne_lock *lock,
-#ifdef HAVE_NEON_026PLUS
                             const ne_uri *uri,
-#else
-                            const char *uri, 
-#endif
 			    const ne_status *status)
 {
     int *ret = userdata;
@@ -349,7 +341,7 @@ static int conditional_put(const char *ifhdr, int *klass, int *code)
     ne_request *req;
     
     req = ne_request_create(i_session, "PUT", res);
-    ne_set_request_body_fd(req, i_foo_fd, 0, i_foo_len);
+    ne_set_request_body_buffer(req, "zero", 4);
 
     ne_print_request_header(req, "If", "%s", ifhdr);
     
